NaMaster: nmt_field Struct Reference

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
nmt_field Struct Reference

Full-sky field. More...

`#include <namaster.h>`

## Data Fields
nmt_curvedsky_info * | cs
| pixelization parameters More...
long | npix
| Number of pixels in all maps. More...
int | lmax
| Maximum multipole used. More...
int | pure_e
| >0 if E-modes have been purified More...
int | pure_b
| >0 if B-modes have been purified More...
flouble * | mask
| Field's mask (an array of `npix` values). More...
fcomplex ** | a_mask
| Spherical transform of the mask. Only computed if E or B are purified. More...
int | spin
| field's spin (>=0). More...
int | nmaps
| Number of maps in the field (2 for spin-2, 1 for spin-0). More...
flouble ** | maps
| Observed field values. When initialized, these maps are already multiplied by the mask, contaminant-deprojected and purified if requested. More...
fcomplex ** | alms
| Spherical harmonic transfoms of the maps. More...
int | ntemp
| Number of contaminant templates. More...
flouble *** | temp
| Contaminant template maps (mask-multiplied but NOT purified). More...
fcomplex *** | a_temp
| Spherical harmonic transfomrs of template maps (mask-multiplied AND purified if requested). More...
gsl_matrix * | matrix_M
| Inverse contaminant covariance matrix (see scientific documentation or companion paper). More...
flouble * | beam
| Field's beam (defined on all multipoles up to `lmax`). More...
int | lite
| lightweight field (no maps, temp, a_temp or a_mask) More...
int | mask_only
| this field only contains a mask, and beam. No alms, maps or anything else. More...

## Detailed Description

Full-sky field.

This structure contains all the information defining a spin-s full-sky field. This includes field values, masking, purification and contamination.

## Field Documentation

fcomplex** nmt_field::a_mask

Spherical transform of the mask. Only computed if E or B are purified.

fcomplex*** nmt_field::a_temp

Spherical harmonic transfomrs of template maps (mask-multiplied AND purified if requested).

fcomplex** nmt_field::alms

Spherical harmonic transfoms of the maps.

flouble* nmt_field::beam

Field's beam (defined on all multipoles up to `lmax`).

nmt_curvedsky_info* nmt_field::cs

pixelization parameters

int nmt_field::lite

lightweight field (no maps, temp, a_temp or a_mask)

int nmt_field::lmax

Maximum multipole used.

flouble** nmt_field::maps

Observed field values. When initialized, these maps are already multiplied by the mask, contaminant-deprojected and purified if requested.

flouble* nmt_field::mask

Field's mask (an array of `npix` values).

int nmt_field::mask_only

this field only contains a mask, and beam. No alms, maps or anything else.

gsl_matrix* nmt_field::matrix_M

Inverse contaminant covariance matrix (see scientific documentation or companion paper).

int nmt_field::nmaps

Number of maps in the field (2 for spin-2, 1 for spin-0).

long nmt_field::npix

Number of pixels in all maps.

int nmt_field::ntemp

Number of contaminant templates.

int nmt_field::pure_b

>0 if B-modes have been purified

int nmt_field::pure_e

>0 if E-modes have been purified

int nmt_field::spin

field's spin (>=0).

flouble*** nmt_field::temp

Contaminant template maps (mask-multiplied but NOT purified).

The documentation for this struct was generated from the following file:

- namaster.h